@@ -14,6 +14,7 @@
  *
  */
 
+#include "version.h"
 #include "network.h"
 #include "osutils.h"
 #include "sysfs.h"
@@ -33,13 +34,13 @@
 #include <sys/types.h>
 using namespace std;
 
-static const char rcsid[] = "@(#) $Id: network.cc 1319 2006-05-09 07:48:12Z ezix $";
+__ID("@(#) $Id: network.cc 1726 2007-02-13 21:38:11Z lyonel $");
 
 #ifndef ARPHRD_IEEE1394
-#define ARPHRD_IEEE1394	24
+#define ARPHRD_IEEE1394 24
 #endif
 #ifndef ARPHRD_SIT
-#define ARPHRD_SIT	776
+#define ARPHRD_SIT  776
 #endif
 
 #ifndef SIOCETHTOOL
@@ -53,23 +54,23 @@ typedef __uint8_t u8;
 struct ethtool_cmd
 {
   u32 cmd;
-  u32 supported;		/* Features this interface supports */
-  u32 advertising;		/* Features this interface advertises */
-  u16 speed;			/* The forced speed, 10Mb, 100Mb, gigabit */
-  u8 duplex;			/* Duplex, half or full */
-  u8 port;			/* Which connector port */
+  u32 supported;                                  /* Features this interface supports */
+  u32 advertising;                                /* Features this interface advertises */
+  u16 speed;                                      /* The forced speed, 10Mb, 100Mb, gigabit */
+  u8 duplex;                                      /* Duplex, half or full */
+  u8 port;                                        /* Which connector port */
   u8 phy_address;
-  u8 transceiver;		/* Which tranceiver to use */
-  u8 autoneg;			/* Enable or disable autonegotiation */
-  u32 maxtxpkt;			/* Tx pkts before generating tx int */
-  u32 maxrxpkt;			/* Rx pkts before generating rx int */
+  u8 transceiver;                                 /* Which tranceiver to use */
+  u8 autoneg;                                     /* Enable or disable autonegotiation */
+  u32 maxtxpkt;                                   /* Tx pkts before generating tx int */
+  u32 maxrxpkt;                                   /* Rx pkts before generating rx int */
   u32 reserved[4];
 };
 
 #ifndef IFNAMSIZ
 #define IFNAMSIZ 32
 #endif
-#define SIOCGIWNAME     0x8B01	/* get name == wireless protocol */
+#define SIOCGIWNAME     0x8B01                    /* get name == wireless protocol */
 /* SIOCGIWNAME is used to verify the presence of Wireless Extensions.
  * Common values : "IEEE 802.11-DS", "IEEE 802.11-FH", "IEEE 802.11b"... */
 
@@ -78,19 +79,19 @@ struct ethtool_cmd
 struct ethtool_drvinfo
 {
   u32 cmd;
-  char driver[32];		/* driver short name, "tulip", "eepro100" */
-  char version[32];		/* driver version string */
-  char fw_version[32];		/* firmware version string, if applicable */
-  char bus_info[ETHTOOL_BUSINFO_LEN];	/* Bus info for this IF. */
-  /*
-   * For PCI devices, use pci_dev->slot_name. 
-   */
+  char driver[32];                                /* driver short name, "tulip", "eepro100" */
+  char version[32];                               /* driver version string */
+  char fw_version[32];                            /* firmware version string, if applicable */
+  char bus_info[ETHTOOL_BUSINFO_LEN];             /* Bus info for this IF. */
+/*
+ * For PCI devices, use pci_dev->slot_name.
+ */
   char reserved1[32];
   char reserved2[16];
-  u32 n_stats;			/* number of u64's from ETHTOOL_GSTATS */
+  u32 n_stats;                                    /* number of u64's from ETHTOOL_GSTATS */
   u32 testinfo_len;
-  u32 eedump_len;		/* Size of data from ETHTOOL_GEEPROM (bytes) */
-  u32 regdump_len;		/* Size of data from ETHTOOL_GREGS (bytes) */
+  u32 eedump_len;                                 /* Size of data from ETHTOOL_GEEPROM (bytes) */
+  u32 regdump_len;                                /* Size of data from ETHTOOL_GREGS (bytes) */
 };
 
 /* for passing single values */
@@ -101,9 +102,9 @@ struct ethtool_value
 };
 
 /* CMDs currently supported */
-#define ETHTOOL_GSET            0x00000001	/* Get settings. */
-#define ETHTOOL_GDRVINFO        0x00000003	/* Get driver info. */
-#define ETHTOOL_GLINK           0x0000000a	/* Get link status (ethtool_value) */
+#define ETHTOOL_GSET            0x00000001        /* Get settings. */
+#define ETHTOOL_GDRVINFO        0x00000003        /* Get driver info. */
+#define ETHTOOL_GLINK           0x0000000a        /* Get link status (ethtool_value) */
 
 /* Indicates what features are supported by the interface. */
 #define SUPPORTED_10baseT_Half          (1 << 0)
@@ -158,13 +159,13 @@ bool load_interfaces(vector < string > &interfaces)
   if (procnetdev.size() <= 2)
     return false;
 
-  // get rid of header (2 lines)
+// get rid of header (2 lines)
   procnetdev.erase(procnetdev.begin());
   procnetdev.erase(procnetdev.begin());
 
   for (unsigned int i = 0; i < procnetdev.size(); i++)
   {
-    // extract interfaces names
+// extract interfaces names
     size_t pos = procnetdev[i].find(':');
 
     if (pos != string::npos)
@@ -174,6 +175,7 @@ bool load_interfaces(vector < string > &interfaces)
   return true;
 }
 
+
 static string getmac(const unsigned char *mac)
 {
   char buff[5];
@@ -198,46 +200,49 @@ static string getmac(const unsigned char *mac)
     return "";
 }
 
+
 static const char *hwname(int t)
 {
   switch (t)
   {
-  case ARPHRD_ETHER:
-    return "Ethernet";
-  case ARPHRD_SLIP:
-    return "SLIP";
-  case ARPHRD_LOOPBACK:
-    return "loopback";
-  case ARPHRD_FDDI:
-    return "FDDI";
-  case ARPHRD_IEEE1394:
-    return "IEEE1394";
-  case ARPHRD_IRDA:
-    return "IRDA";
-  case ARPHRD_PPP:
-    return "PPP";
-  case ARPHRD_X25:
-    return "X25";
-  case ARPHRD_TUNNEL:
-    return "IPtunnel";
-  case ARPHRD_DLCI:
-    return "Framerelay.DLCI";
-  case ARPHRD_FRAD:
-    return "Framerelay.AD";
-  case ARPHRD_TUNNEL6:
-    return "IP6tunnel";
-  case ARPHRD_SIT:
-    return "IP6inIP4";
-  default:
-    return "";
+    case ARPHRD_ETHER:
+      return "Ethernet";
+    case ARPHRD_SLIP:
+      return "SLIP";
+    case ARPHRD_LOOPBACK:
+      return "loopback";
+    case ARPHRD_FDDI:
+      return "FDDI";
+    case ARPHRD_IEEE1394:
+      return "IEEE1394";
+    case ARPHRD_IRDA:
+      return "IRDA";
+    case ARPHRD_PPP:
+      return "PPP";
+    case ARPHRD_X25:
+      return "X25";
+    case ARPHRD_TUNNEL:
+      return "IPtunnel";
+    case ARPHRD_DLCI:
+      return "Framerelay.DLCI";
+    case ARPHRD_FRAD:
+      return "Framerelay.AD";
+    case ARPHRD_TUNNEL6:
+      return "IP6tunnel";
+    case ARPHRD_SIT:
+      return "IP6inIP4";
+    default:
+      return "";
   }
 }
 
+
 static string print_ip(struct sockaddr_in *in)
 {
   return string(inet_ntoa(in->sin_addr));
 }
 
+
 static void scan_ip(hwNode & interface)
 {
   int fd = socket(AF_INET, SOCK_DGRAM, 0);
@@ -246,21 +251,21 @@ static void scan_ip(hwNode & interface)
   {
     struct ifreq ifr;
 
-    // get IP address
+// get IP address
     memset(&ifr, 0, sizeof(ifr));
     strcpy(ifr.ifr_name, interface.getLogicalName().c_str());
     ifr.ifr_addr.sa_family = AF_INET;
     if (ioctl(fd, SIOCGIFADDR, &ifr) == 0)
     {
-      // IP address is in ifr.ifr_addr
+// IP address is in ifr.ifr_addr
       interface.setConfig("ip", print_ip((sockaddr_in *) (&ifr.ifr_addr)));
       strcpy(ifr.ifr_name, interface.getLogicalName().c_str());
       if ((interface.getConfig("point-to-point") == "yes")
-	  && (ioctl(fd, SIOCGIFDSTADDR, &ifr) == 0))
+        && (ioctl(fd, SIOCGIFDSTADDR, &ifr) == 0))
       {
-	// remote PPP address is in ifr.ifr_dstaddr
-	interface.setConfig("remoteip",
-			    print_ip((sockaddr_in *) & ifr.ifr_dstaddr));
+// remote PPP address is in ifr.ifr_dstaddr
+        interface.setConfig("remoteip",
+          print_ip((sockaddr_in *) & ifr.ifr_dstaddr));
       }
     }
 
@@ -268,6 +273,7 @@ static void scan_ip(hwNode & interface)
   }
 }
 
+
 static bool isVMware(const string & MAC)
 {
   if (MAC.length() < 8)
@@ -276,12 +282,13 @@ static bool isVMware(const string & MAC)
   string manufacturer = uppercase(MAC.substr(0, 8));
 
   if ((manufacturer == "00:05:69") ||
-      (manufacturer == "00:0C:29") || (manufacturer == "00:50:56"))
+    (manufacturer == "00:0C:29") || (manufacturer == "00:50:56"))
     return true;
 
   return false;
 }
 
+
 bool scan_network(hwNode & n)
 {
   vector < string > interfaces;
@@ -302,7 +309,7 @@ bool scan_network(hwNode & n)
     for (unsigned int i = 0; i < interfaces.size(); i++)
     {
       hwNode interface("network",
-		       hw::network);
+        hw::network);
 
       interface.setLogicalName(interfaces[i]);
       interface.claim();
@@ -311,7 +318,7 @@ bool scan_network(hwNode & n)
       string businfo = sysfs_getbusinfo(sysfs::entry::byClass("net", interface.getLogicalName()));
       interface.setBusInfo(businfo);
 
-      //scan_mii(fd, interface);
+//scan_mii(fd, interface);
       scan_ip(interface);
 
       memset(&ifr, 0, sizeof(ifr));
@@ -319,62 +326,62 @@ bool scan_network(hwNode & n)
       if (ioctl(fd, SIOCGIFFLAGS, &ifr) == 0)
       {
 #ifdef IFF_PORTSEL
-	if (ifr.ifr_flags & IFF_PORTSEL)
-	{
-	  if (ifr.ifr_flags & IFF_AUTOMEDIA)
-	    interface.setConfig("automedia", "yes");
-	}
+        if (ifr.ifr_flags & IFF_PORTSEL)
+        {
+          if (ifr.ifr_flags & IFF_AUTOMEDIA)
+            interface.setConfig("automedia", "yes");
+        }
 #endif
 
-	if (ifr.ifr_flags & IFF_UP)
-	  interface.enable();
-	else
-	  interface.disable();
-	if (ifr.ifr_flags & IFF_BROADCAST)
-	  interface.setConfig("broadcast", "yes");
-	if (ifr.ifr_flags & IFF_DEBUG)
-	  interface.setConfig("debug", "yes");
-	if (ifr.ifr_flags & IFF_LOOPBACK)
-	  interface.setConfig("loopback", "yes");
-	if (ifr.ifr_flags & IFF_POINTOPOINT)
-	  interface.setConfig("point-to-point", "yes");
-	if (ifr.ifr_flags & IFF_PROMISC)
-	  interface.setConfig("promiscuous", "yes");
-	if (ifr.ifr_flags & IFF_SLAVE)
-	  interface.setConfig("slave", "yes");
-	if (ifr.ifr_flags & IFF_MASTER)
-	  interface.setConfig("master", "yes");
-	if (ifr.ifr_flags & IFF_MULTICAST)
-	  interface.setConfig("multicast", "yes");
+        if (ifr.ifr_flags & IFF_UP)
+          interface.enable();
+        else
+          interface.disable();
+        if (ifr.ifr_flags & IFF_BROADCAST)
+          interface.setConfig("broadcast", "yes");
+        if (ifr.ifr_flags & IFF_DEBUG)
+          interface.setConfig("debug", "yes");
+        if (ifr.ifr_flags & IFF_LOOPBACK)
+          interface.setConfig("loopback", "yes");
+        if (ifr.ifr_flags & IFF_POINTOPOINT)
+          interface.setConfig("point-to-point", "yes");
+        if (ifr.ifr_flags & IFF_PROMISC)
+          interface.setConfig("promiscuous", "yes");
+        if (ifr.ifr_flags & IFF_SLAVE)
+          interface.setConfig("slave", "yes");
+        if (ifr.ifr_flags & IFF_MASTER)
+          interface.setConfig("master", "yes");
+        if (ifr.ifr_flags & IFF_MULTICAST)
+          interface.setConfig("multicast", "yes");
       }
 
       memset(&ifr, 0, sizeof(ifr));
       strcpy(ifr.ifr_name, interfaces[i].c_str());
-      // get MAC address
+// get MAC address
       if (ioctl(fd, SIOCGIFHWADDR, &ifr) == 0)
       {
-	string hwaddr = getmac((unsigned char *) ifr.ifr_hwaddr.sa_data);
-	interface.addCapability(hwname(ifr.ifr_hwaddr.sa_family));
-	if (ifr.ifr_hwaddr.sa_family >= 256)
-	  interface.addCapability("logical", "Logical interface");
-	else
-	  interface.addCapability("physical", "Physical interface");
-	interface.setDescription(string(hwname(ifr.ifr_hwaddr.sa_family)) +
-				 " interface");
-	interface.setSerial(hwaddr);
+        string hwaddr = getmac((unsigned char *) ifr.ifr_hwaddr.sa_data);
+        interface.addCapability(hwname(ifr.ifr_hwaddr.sa_family));
+        if (ifr.ifr_hwaddr.sa_family >= 256)
+          interface.addCapability("logical", "Logical interface");
+        else
+          interface.addCapability("physical", "Physical interface");
+        interface.setDescription(string(hwname(ifr.ifr_hwaddr.sa_family)) +
+          " interface");
+        interface.setSerial(hwaddr);
 
-	if (isVMware(interface.getSerial()))
-	  interface.addCapability("logical", "Logical interface");
+        if (isVMware(interface.getSerial()))
+          interface.addCapability("logical", "Logical interface");
       }
 
-      // check for wireless extensions
+// check for wireless extensions
       memset(buffer, 0, sizeof(buffer));
       strncpy(buffer, interfaces[i].c_str(), sizeof(buffer));
       if (ioctl(fd, SIOCGIWNAME, &buffer) == 0)
       {
-	interface.addCapability("wireless", "Wireless-LAN");
-	interface.setConfig("wireless", hw::strip(buffer + IFNAMSIZ));
-	interface.setDescription("Wireless interface");
+        interface.addCapability("wireless", "Wireless-LAN");
+        interface.setConfig("wireless", hw::strip(buffer + IFNAMSIZ));
+        interface.setDescription("Wireless interface");
         interface.addHint("icon", string("wifi"));
         interface.addHint("bus.icon", string("radio"));
       }
@@ -436,7 +443,7 @@ bool scan_network(hwNode & n)
         }
         if(ecmd.supported & SUPPORTED_Autoneg)
           interface.addCapability("autonegotiation", "Auto-negotiation");
-        
+
         switch(ecmd.speed)
         {
           case SPEED_10:
@@ -488,33 +495,33 @@ bool scan_network(hwNode & n)
       ifr.ifr_data = (caddr_t) & drvinfo;
       if (ioctl(fd, SIOCETHTOOL, &ifr) == 0)
       {
-	interface.setConfig("driver", drvinfo.driver);
-	interface.setConfig("driverversion", drvinfo.version);
-	interface.setConfig("firmware", drvinfo.fw_version);
-	if (interface.getBusInfo() == "")
-	  interface.setBusInfo(guessBusInfo(drvinfo.bus_info));
+        interface.setConfig("driver", drvinfo.driver);
+        interface.setConfig("driverversion", drvinfo.version);
+        interface.setConfig("firmware", drvinfo.fw_version);
+        if (interface.getBusInfo() == "")
+          interface.setBusInfo(guessBusInfo(drvinfo.bus_info));
       }
 
       if (hwNode * existing = n.findChildByBusInfo(interface.getBusInfo()))
       {
-	existing->merge(interface);
-	if(interface.getDescription()!="")
+        existing->merge(interface);
+        if(interface.getDescription()!="")
           existing->setDescription(interface.getDescription());
       }
       else
       {
-	existing = n.findChildByLogicalName(interface.getLogicalName());
-	if (existing)
-	{
-	  existing->merge(interface);
-	}
-	else
-	{
-	  // we don't care about loopback and "logical" interfaces
-	  if (!interface.isCapable("loopback") &&
-	      !interface.isCapable("logical"))
-	    n.addChild(interface);
-	}
+        existing = n.findChildByLogicalName(interface.getLogicalName());
+        if (existing)
+        {
+          existing->merge(interface);
+        }
+        else
+        {
+// we don't care about loopback and "logical" interfaces
+          if (!interface.isCapable("loopback") &&
+            !interface.isCapable("logical"))
+            n.addChild(interface);
+        }
       }
     }
 
